import streamlit as st
import streamlit_echarts
import streamlit_authenticator as stauth
import yaml
from yaml.loader import SafeLoader
from utils import logger
import datetime
from utils.prophet_models import generate_df_with_days, load_c1_model, load_c2_model, load_c1_plus_c2_model, build_echart_compare, load_june

st.set_page_config(layout="wide", page_title="Comparação")
with open("config.yaml") as file:
    config = yaml.load(file, Loader=SafeLoader)

authenticator = stauth.Authenticate(
    config["credentials"],
    config["cookie"]["name"],
    config["cookie"]["key"],
    config["cookie"]["expiry_days"],
)

authenticator.login("Login", "main")
if st.session_state["authentication_status"]:
    st.sidebar.write(f'Olá **{st.session_state["name"]}** 👑!')
    authenticator.logout("Logout", "sidebar")
    logger_utils = logger.Logger(st.session_state["name"])
    
    with st.spinner("A carregar os dados..."):
        next_year = 2023
        base_inital_date = datetime.date(2023, 1, 1)
        initial = datetime.date(next_year, 6, 1)
        final = datetime.date(next_year, 6, 30)
    
        days = (final - base_inital_date).days + 1
        future_df = generate_df_with_days(days, load_c1_model)
        june_df = load_june()
        logger_utils.log("Building predictions graphs")
        st.subheader("Comparação de Mediana por dia para Nacionais em Junho de 2023")
        df_future = generate_df_with_days(days, load_c1_model)
        
        streamlit_echarts.st_echarts(build_echart_compare(list(june_df["C1"]), df_future, initial))
        
        st.subheader("Comparação de Mediana por dia para Roamers em Junho de 2023")
        df_future = generate_df_with_days(days, load_c2_model)

        streamlit_echarts.st_echarts(build_echart_compare(list(june_df["C2"]), df_future, initial))
        
        st.subheader("Comparação de Mediana por dia para Nacionais mais Roamers em Junho de 2023")
        df_future = generate_df_with_days(days, load_c1_plus_c2_model)

        streamlit_echarts.st_echarts(build_echart_compare(list(june_df["C1+C2"]), df_future, initial))


elif st.session_state["authentication_status"] is False:
    st.error("Username/password incorretos")