import streamlit as st
import streamlit_echarts
import streamlit_authenticator as stauth
import yaml
from yaml.loader import SafeLoader
from utils import logger
import datetime
from utils.prophet_models import generate_df_with_days, load_c1_model, load_c2_model, load_c1_plus_c2_model, build_echart

st.set_page_config(layout="wide", page_title="Previsões")
with open("config.yaml") as file:
    config = yaml.load(file, Loader=SafeLoader)

authenticator = stauth.Authenticate(
    config["credentials"],
    config["cookie"]["name"],
    config["cookie"]["key"],
    config["cookie"]["expiry_days"],
)

authenticator.login("Login", "main")
if st.session_state["authentication_status"]:
    st.sidebar.write(f'Olá **{st.session_state["name"]}** 👑!')
    authenticator.logout("Logout", "sidebar")
    logger_utils = logger.Logger(st.session_state["name"])
    next_year = 2023
    jan_1 = datetime.date(next_year, 1, 1)
    dec_31 = datetime.date(next_year, 12, 31)

    pair_date = st.sidebar.date_input(
        "Data Inicial",
        (jan_1, datetime.date(next_year, 1, 31)),
        jan_1,
        dec_31,
        format="DD/MM/YYYY",
    )
    
    generate_button = st.sidebar.button(
        "Gerar dados",
    )
    
    if generate_button:
        
        base_inital_date = datetime.date(2023, 1, 1)
        days = (pair_date[1] - base_inital_date).days + 1
        with st.spinner("A carregar os dados..."):
            logger_utils.log("Building predictions graphs")
            st.subheader("Previsões de Mediana por dia para Nacionais")
            df = generate_df_with_days(days, load_c1_model)
            streamlit_echarts.st_echarts(build_echart(df, pair_date[0]))
        with st.spinner("A carregar os dados..."):
            logger_utils.log("Building predictions graphs")
            st.subheader("Previsões de Mediana por dia para Roamers")
            df = generate_df_with_days(days, load_c2_model)
            streamlit_echarts.st_echarts(build_echart(df, pair_date[0]))
        with st.spinner("A carregar os dados..."):
            logger_utils.log("Building predictions graphs")
            st.subheader("Previsões de Mediana por dia para Nacionais mais Roamers")
            df = generate_df_with_days(days, load_c1_plus_c2_model)
            streamlit_echarts.st_echarts(build_echart(df, pair_date[0]))
        
        
elif st.session_state["authentication_status"] is False:
    st.error("Username/password incorretos")