import pandas as pd
from prophet.serialize import model_from_json


def load_c1_model():
    with open("prophet_ds_c1.json", "r") as fin:
        m = model_from_json(fin.read())
        return m


def load_c2_model():
    with open("prophet_ds_c2.json", "r") as fin:
        m = model_from_json(fin.read())
        return m


def load_c1_plus_c2_model():
    with open("prophet_ds_c1c2.json", "r") as fin:
        m = model_from_json(fin.read())
        return m


def generate_df_with_days(days, builder_model):
    m = builder_model()
    future = m.make_future_dataframe(periods=days)
    return m.predict(future)


def build_echart(df, initial_date):
    df = df[df["ds"] >= pd.to_datetime(initial_date)]
    return {
        "tooltip": {
            "trigger": "axis",
            "axisPointer": {
                "type": "cross",
                "label": {"backgroundColor": "#6a7985"},
            },
        },
        "legend": {"data": ["Valor", "Minímo", "Máximo"]},
        "grid": {
            "left": "3%",
            "right": "4%",
            "bottom": "3%",
            "containLabel": True,
        },
        "xAxis": [
            {
                "type": "category",
                "boundaryGap": False,
                "data": list(df["ds"].dt.strftime("%d-%m-%Y")),
            }
        ],
        "yAxis": [{"type": "value"}],
        "series": [
            {
                "name": "Valor",
                "type": "line",
                "areaStyle": {"color": "none"},
                "emphasis": {"focus": "series"},
                "data": list(df["yhat"]),
            },
            {
                "name": "Minímo",
                "type": "line",
                "areaStyle": {"color": "none"},
                "emphasis": {"focus": "series"},
                "data": list(df["yhat_lower"]),
                "lineStyle": {"type": "dashed"},
            },
            {
                "name": "Máximo",
                "type": "line",
                "areaStyle": {"color": "none"},
                "emphasis": {"focus": "series"},
                "data": list(df["yhat_upper"]),
                "lineStyle": {"type": "dashed"},
            },
        ],
    }


def load_june():
    return pd.read_parquet("./prophet_june_2023.parquet")


def build_echart_compare(values, future, initial_date):
    df_future = future[future["ds"] >= pd.to_datetime(initial_date)]
    return {
        "tooltip": {
            "trigger": "axis",
            "axisPointer": {
                "type": "cross",
                "label": {"backgroundColor": "#6a7985"},
            },
        },
        "legend": {"data": ["Valor", "Predição", "Predição - Max", "Predição - Min"]},
        "grid": {
            "left": "3%",
            "right": "4%",
            "bottom": "3%",
            "containLabel": True,
        },
        "xAxis": [
            {
                "type": "category",
                "boundaryGap": False,
                "data": list(df_future["ds"].dt.strftime("%d-%m-%Y")),
            }
        ],
        "yAxis": [{"type": "value"}],
        "series": [
            {
                "name": "Valor",
                "type": "line",
                "areaStyle": {"color": "none"},
                "emphasis": {"focus": "series"},
                "data": list(values),
            },
            {
                "name": "Predição",
                "type": "line",
                "areaStyle": {"color": "none"},
                "emphasis": {"focus": "series"},
                "data": list(df_future["yhat"]),
                "lineStyle": {"type": "dashed"},
            },
            {
                "name": "Predição - Max",
                "type": "line",
                "areaStyle": {"color": "none"},
                "emphasis": {"focus": "series"},
                "data": list(df_future["yhat_upper"]),
                "lineStyle": {"type": "dashed"},
            },
            {
                "name": "Predição - Min",
                "type": "line",
                "areaStyle": {"color": "none"},
                "emphasis": {"focus": "series"},
                "data": list(df_future["yhat_lower"]),
                "lineStyle": {"type": "dashed"},
            },
        ],
    }
